@@ -1232,131 +1232,131 @@ gnumeric_imsum (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 
 GnmFuncDescriptor const complex_functions[] = {
         { "complex",     "ff|s",  help_complex,
-	  gnumeric_complex, NULL, NULL, NULL, NULL,
+	  gnumeric_complex, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imabs",       "S",     help_imabs,
-	  gnumeric_imabs, NULL, NULL, NULL, NULL,
+	  gnumeric_imabs, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imaginary",   "S",     help_imaginary,
-	  gnumeric_imaginary, NULL, NULL, NULL, NULL,
+	  gnumeric_imaginary, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imargument",  "S",     help_imargument,
-	  gnumeric_imargument, NULL, NULL, NULL, NULL,
+	  gnumeric_imargument, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imconjugate", "S",     help_imconjugate,
-	  gnumeric_imconjugate, NULL, NULL, NULL, NULL,
+	  gnumeric_imconjugate, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imcos",       "S",     help_imcos,
-	  gnumeric_imcos, NULL, NULL, NULL, NULL,
+	  gnumeric_imcos, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imdiv",       "SS",    help_imdiv,
-	  gnumeric_imdiv, NULL, NULL, NULL, NULL,
+	  gnumeric_imdiv, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imexp",       "S",     help_imexp,
-	  gnumeric_imexp, NULL, NULL, NULL, NULL,
+	  gnumeric_imexp, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imln",        "S",     help_imln,
-	  gnumeric_imln, NULL, NULL, NULL, NULL,
+	  gnumeric_imln, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imlog10",     "S",     help_imlog10,
-	  gnumeric_imlog10, NULL, NULL, NULL, NULL,
+	  gnumeric_imlog10, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imlog2",      "S",     help_imlog2,
-	  gnumeric_imlog2, NULL, NULL, NULL, NULL,
+	  gnumeric_imlog2, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "impower",     "SS",    help_impower,
-	  gnumeric_impower, NULL, NULL, NULL, NULL,
+	  gnumeric_impower, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imreal",      "S",     help_imreal,
-	  gnumeric_imreal, NULL, NULL, NULL, NULL,
+	  gnumeric_imreal, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imsin",       "S",     help_imsin,
-	  gnumeric_imsin, NULL, NULL, NULL, NULL,
+	  gnumeric_imsin, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imsqrt",      "S",     help_imsqrt,
-	  gnumeric_imsqrt, NULL, NULL, NULL, NULL,
+	  gnumeric_imsqrt, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imsub",       "SS",    help_imsub,
-	  gnumeric_imsub, NULL, NULL, NULL, NULL,
+	  gnumeric_imsub, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imsum",       NULL,    help_imsum,
-	  NULL, gnumeric_imsum, NULL, NULL, NULL,
+	  NULL, gnumeric_imsum, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
         { "iminv",   "S",     help_iminv,
-	  gnumeric_iminv, NULL, NULL, NULL, NULL,
+	  gnumeric_iminv, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "imneg",   "S",     help_imneg,
-	  gnumeric_imneg, NULL, NULL, NULL, NULL,
+	  gnumeric_imneg, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imtan",       "S",     help_imtan,
-	  gnumeric_imtan, NULL, NULL, NULL, NULL,
+	  gnumeric_imtan, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "improduct",   NULL,    help_improduct,
-	  NULL, gnumeric_improduct, NULL, NULL, NULL,
+	  NULL, gnumeric_improduct, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imsec",       "S",     help_imsec,
-	  gnumeric_imsec, NULL, NULL, NULL, NULL,
+	  gnumeric_imsec, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imcsc",       "S",     help_imcsc,
-	  gnumeric_imcsc, NULL, NULL, NULL, NULL,
+	  gnumeric_imcsc, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imcot",       "S",     help_imcot,
-	  gnumeric_imcot, NULL, NULL, NULL, NULL,
+	  gnumeric_imcot, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imsinh",       "S",    help_imsinh,
-	  gnumeric_imsinh, NULL, NULL, NULL, NULL,
+	  gnumeric_imsinh, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imcosh",       "S",    help_imcosh,
-	  gnumeric_imcosh, NULL, NULL, NULL, NULL,
+	  gnumeric_imcosh, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imtanh",       "S",    help_imtanh,
-	  gnumeric_imtanh, NULL, NULL, NULL, NULL,
+	  gnumeric_imtanh, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imsech",       "S",    help_imsech,
-	  gnumeric_imsech, NULL, NULL, NULL, NULL,
+	  gnumeric_imsech, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imcsch",       "S",    help_imcsch,
-	  gnumeric_imcsch, NULL, NULL, NULL, NULL,
+	  gnumeric_imcsch, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imcoth",       "S",    help_imcoth,
-	  gnumeric_imcoth, NULL, NULL, NULL, NULL,
+	  gnumeric_imcoth, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarcsin",     "S",    help_imarcsin,
-	  gnumeric_imarcsin, NULL, NULL, NULL, NULL,
+	  gnumeric_imarcsin, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarccos",     "S",    help_imarccos,
-	  gnumeric_imarccos, NULL, NULL, NULL, NULL,
+	  gnumeric_imarccos, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarctan",     "S",    help_imarctan,
-	  gnumeric_imarctan, NULL, NULL, NULL, NULL,
+	  gnumeric_imarctan, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarcsec",     "S",    help_imarcsec,
-	  gnumeric_imarcsec, NULL, NULL, NULL, NULL,
+	  gnumeric_imarcsec, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarccsc",     "S",    help_imarccsc,
-	  gnumeric_imarccsc, NULL, NULL, NULL, NULL,
+	  gnumeric_imarccsc, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarccot",     "S",    help_imarccot,
-	  gnumeric_imarccot, NULL, NULL, NULL, NULL,
+	  gnumeric_imarccot, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarcsinh",    "S",    help_imarcsinh,
-	  gnumeric_imarcsinh, NULL, NULL, NULL, NULL,
+	  gnumeric_imarcsinh, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarccosh",    "S",    help_imarccosh,
-	  gnumeric_imarccosh, NULL, NULL, NULL, NULL,
+	  gnumeric_imarccosh, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarctanh",    "S",    help_imarctanh,
-	  gnumeric_imarctanh, NULL, NULL, NULL, NULL,
+	  gnumeric_imarctanh, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarcsech",    "S",    help_imarcsech,
-	  gnumeric_imarcsech, NULL, NULL, NULL, NULL,
+	  gnumeric_imarcsech, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarccsch",    "S",    help_imarccsch,
-	  gnumeric_imarccsch, NULL, NULL, NULL, NULL,
+	  gnumeric_imarccsch, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "imarccoth",    "S",    help_imarccoth,
-	  gnumeric_imarccoth, NULL, NULL, NULL, NULL,
+	  gnumeric_imarccoth, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         {NULL}
 };
