@@ -206,7 +206,7 @@ gnm_compare_strings (const char *cstr1, const char *cstr2)
 	/* then it is exactly the same. */
 	while (*a == *b && *a != 0 && *b != 0)
 		a++, b++;
-	
+
 	if (*a == 0)
 		return (*b == 0);
 	if (*b == 0)
@@ -226,17 +226,17 @@ gnm_compare_strings (const char *cstr1, const char *cstr2)
 	/* are both expanded by NFD (or NFKD) into the sequence */
 	/*"U+0041 U+030A" (Latin letter "A" and combining ring above "°") */
 	/* Of course "U+0041 U+030A" is retained in form, so we need to work with */
-	/* at least the last ASCII character. Performance should nearly be */ 
+	/* at least the last ASCII character. Performance should nearly be */
 	/* identical to using all */
 
 	str1 = g_utf8_normalize (cstr1, -1, G_NORMALIZE_DEFAULT);
 	str2 = g_utf8_normalize (cstr2, -1, G_NORMALIZE_DEFAULT);
-	
+
 	val = (g_strcmp0 (str1, str2) == 0);
-	
+
 	g_free (str1);
 	g_free (str2);
-	
+
 	return val;
 }
 
@@ -1677,109 +1677,109 @@ gnumeric_jis (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 /***************************************************************************/
 GnmFuncDescriptor const string_functions[] = {
         { "asc",       "s",                       help_asc,
-	  gnumeric_asc, NULL, NULL, NULL, NULL,
+	  gnumeric_asc, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "char",       "f",                       help_char,
-	  gnumeric_char, NULL, NULL, NULL, NULL,
+	  gnumeric_char, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "unichar",    "f",                       help_unichar,
-	  gnumeric_unichar, NULL, NULL, NULL, NULL,
+	  gnumeric_unichar, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_BASIC },
         { "clean",      "S",                         help_clean,
-          gnumeric_clean, NULL, NULL, NULL, NULL,
+          gnumeric_clean, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "code",       "S",                         help_code,
-	  gnumeric_code, NULL, NULL, NULL, NULL,
+	  gnumeric_code, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "unicode",    "S",                         help_unicode,
-	  gnumeric_unicode, NULL, NULL, NULL, NULL,
+	  gnumeric_unicode, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_BASIC },
         { "concatenate", NULL,               help_concatenate,
-	  NULL, gnumeric_concatenate, NULL, NULL, NULL,
+	  NULL, gnumeric_concatenate, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "dollar",     "f|f",               help_dollar,
-	  gnumeric_dollar, NULL, NULL, NULL, NULL,
+	  gnumeric_dollar, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "exact",      "SS",                 help_exact,
-	  gnumeric_exact, NULL, NULL, NULL, NULL,
+	  gnumeric_exact, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "find",       "SS|f",           help_find,
-	  gnumeric_find, NULL, NULL, NULL, NULL,
+	  gnumeric_find, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "findb",       "SS|f",           help_findb,
-	  gnumeric_findb, NULL, NULL, NULL, NULL,
+	  gnumeric_findb, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "fixed",      "f|fb",        help_fixed,
-	  gnumeric_fixed, NULL, NULL, NULL, NULL,
+	  gnumeric_fixed, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "jis",       "s",                       help_jis,
-	  gnumeric_jis, NULL, NULL, NULL, NULL,
+	  gnumeric_jis, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "left",       "S|f",             help_left,
-	  gnumeric_left, NULL, NULL, NULL, NULL,
+	  gnumeric_left, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "leftb",       "S|f",             help_leftb,
-	  gnumeric_leftb, NULL, NULL, NULL, NULL,
+	  gnumeric_leftb, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "len",        "S",                         help_len,
-	  gnumeric_len, NULL, NULL, NULL, NULL,
+	  gnumeric_len, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "lenb",       "S",                         help_lenb,
-	  gnumeric_lenb, NULL, NULL, NULL, NULL,
+	  gnumeric_lenb, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "lower",      "S",                         help_lower,
-	  gnumeric_lower, NULL, NULL, NULL, NULL,
+	  gnumeric_lower, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "mid",        "Sff",               help_mid,
-	  gnumeric_mid, NULL, NULL, NULL, NULL,
+	  gnumeric_mid, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "midb",        "Sff",               help_midb,
-	  gnumeric_midb, NULL, NULL, NULL, NULL,
+	  gnumeric_midb, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "numbervalue",      "SS",          help_numbervalue,
-	  gnumeric_numbervalue, NULL, NULL, NULL, NULL,
+	  gnumeric_numbervalue, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_BASIC },
         { "proper",     "S",                         help_proper,
-	  gnumeric_proper, NULL, NULL, NULL, NULL,
+	  gnumeric_proper, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "replace",    "SffS",         help_replace,
-	  gnumeric_replace, NULL, NULL, NULL, NULL,
+	  gnumeric_replace, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "replaceb",    "SffS",         help_replaceb,
-	  gnumeric_replaceb, NULL, NULL, NULL, NULL,
+	  gnumeric_replaceb, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "rept",       "Sf",                    help_rept,
-	  gnumeric_rept, NULL, NULL, NULL, NULL,
+	  gnumeric_rept, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "right",      "S|f",             help_right,
-	  gnumeric_right, NULL, NULL, NULL, NULL,
+	  gnumeric_right, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "rightb",       "S|f",             help_rightb,
-	  gnumeric_rightb, NULL, NULL, NULL, NULL,
+	  gnumeric_rightb, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "search",     "SS|f",     help_search,
-	  gnumeric_search, NULL, NULL, NULL, NULL,
+	  gnumeric_search, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "searchb",     "SS|f",     help_searchb,
-	  gnumeric_searchb, NULL, NULL, NULL, NULL,
+	  gnumeric_searchb, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "substitute", "SSS|f",        help_substitute,
-	  gnumeric_substitute, NULL, NULL, NULL, NULL,
+	  gnumeric_substitute, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "t",          "S",                        help_t_,
-          gnumeric_t_, NULL, NULL, NULL, NULL,
+          gnumeric_t_, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "text",       "Ss",           help_text,
-	  gnumeric_text, NULL, NULL, NULL, NULL,
+	  gnumeric_text, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "trim",       "S",                         help_trim,
-	  gnumeric_trim, NULL, NULL, NULL, NULL,
+	  gnumeric_trim, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "upper",      "S",                         help_upper,
-	  gnumeric_upper, NULL, NULL, NULL, NULL,
+	  gnumeric_upper, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "value",      "S",                         help_value,
-	  gnumeric_value, NULL, NULL, NULL, NULL,
+	  gnumeric_value, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
         {NULL}
