@@ -231,10 +231,11 @@ linear_averaging (const gnm_float *absc, const gnm_float *ord, int nb_knots,
 			slope = (ord[j] - ord[k]) / x0 / 2.;
 			res[i - 1] += x0 * (slope * x0 + ord[k]);
 		}
-		if (j > k - 1) {
+		if (j > k + 1) {
 			k = j - 1;
 			slope = (ord[j] - ord[k]) / (absc[j] - absc[k]) / 2.;
-		}
+		} else
+			k = j;
 		x0 = targets[i] - absc[k];
 		res[i - 1] += x0 * (slope * x0 + ord[k]);
 		res[i - 1] /= (targets[i] - targets[i - 1]);
@@ -378,20 +379,26 @@ typedef  gnm_float* (*INTERPPROC) (const gnm_float*, const gnm_float*,
 
 static GnmFuncHelp const help_interpolation[] = {
 	{ GNM_FUNC_HELP_NAME, F_("INTERPOLATION:interpolated values corresponding to the given abscissa targets") },
-	{ GNM_FUNC_HELP_ARG, F_("abscissae:ordered abscissae of the given data points") },
+	{ GNM_FUNC_HELP_ARG, F_("abscissae:abscissae of the given data points") },
 	{ GNM_FUNC_HELP_ARG, F_("ordinates:ordinates of the given data points") },
 	{ GNM_FUNC_HELP_ARG, F_("targets:abscissae of the interpolated data") },
 	{ GNM_FUNC_HELP_ARG, F_("interpolation:method of interpolation, defaults to 0 (\'linear\')") },
 	{ GNM_FUNC_HELP_DESCRIPTION, F_("The output consists always of one column of numbers.") },
 	INTERPOLATIONMETHODS,
-	{ GNM_FUNC_HELP_NOTE, F_("The @{abscissae} must be given in increasing order.") },
+	{ GNM_FUNC_HELP_NOTE, F_("The @{abscissae} should be given in increasing order. If the @{abscissae} is not in "
+				 "increasing order the INTERPOLATION function is significantly slower.") },
+	{ GNM_FUNC_HELP_NOTE, F_("If any two @{abscissae} values are equal an error is returned.") },
 	{ GNM_FUNC_HELP_NOTE, F_("If any of interpolation methods 1 ('linear with averaging'), 3 "
 				 "('staircase with averaging'), and 5 ('natural cubic spline with "
 				 "averaging') is used, the number "
-				 "of returned values is one less than the number of targets and the targets "
-				 "values must be given in increasing order.") },
+				 "of returned values is one less than the number of targets and the target "
+				 "values must be given in increasing order. The values returned "
+				 "are the average heights of the interpolation function on the intervals "
+				 "determined by consecutive target values.") },
 	{ GNM_FUNC_HELP_NOTE, F_("Strings and empty cells in @{abscissae} and @{ordinates} are ignored.") },
 	{ GNM_FUNC_HELP_NOTE, F_("If several target data are provided they must be in the same column in consecutive cells.") },
+	{ GNM_FUNC_HELP_EXAMPLES, "=interpolation(array(1,2,3),array(10,20,20),1.5,0)" },
+	{ GNM_FUNC_HELP_EXAMPLES, "=interpolation(array(1,2,3),array(10,20,20),array(1.5,4),1)" },
 	{ GNM_FUNC_HELP_SEEALSO, "PERIODOGRAM" },
 	{ GNM_FUNC_HELP_END, NULL }
 };
@@ -430,12 +437,6 @@ gnumeric_interpolation (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 		return error;
 	}
 
-	if (n2 <= 0) {
-		g_slist_free (missing2);
-		g_free (vals2);
-		return value_new_error_std (ei->pos, GNM_ERROR_VALUE);
-	}
-
 	/* argv[3] */
 
 	if (argv[3]) {
@@ -472,6 +473,12 @@ gnumeric_interpolation (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 		break;
 	}
 
+	if (n2 <= 0) {
+		g_slist_free (missing2);
+		g_free (vals2);
+		return value_new_error_std (ei->pos, GNM_ERROR_VALUE);
+	}
+
 	/* argv[0] & argv[1] */
 
 	flags = COLLECT_IGNORE_BLANKS | COLLECT_IGNORE_STRINGS | COLLECT_IGNORE_BOOLS;
@@ -484,10 +491,36 @@ gnumeric_interpolation (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 		return error;
 	}
 
-	/* Check whether the abscissaa are increasing, if not an error is returned */
-	if (!gnm_range_increasing (vals0, n0))
-		res = value_new_error_std (ei->pos, GNM_ERROR_VALUE);
-	else {
+	/* Check whether the abscissae are increasing, if not order them */
+	if (!gnm_range_increasing (vals0, n0)) {
+		gboolean switched = TRUE;
+		if (constp) {
+			vals0 = g_memdup (vals0, sizeof(gnm_float) * n0);
+			vals1 = g_memdup (vals1, sizeof(gnm_float) * n0);
+			constp = FALSE;
+		}
+		while (switched) {
+			gnm_float *val;
+			switched = FALSE;
+			for (i = 1, val = vals0; i < n0; i++, val++) {
+				if (*val == *(val + 1)) {
+					res = value_new_error_std (ei->pos, GNM_ERROR_VALUE) ;
+					goto done;
+				}
+				if (*val > *(val + 1)) {
+					gnm_float v = *val;
+					*val = *(val + 1);
+					*(val + 1) = v;
+					v = *(vals1 + i);
+					*(vals1 + i) = *(vals1 + i - 1);
+					*(vals1 + i - 1) = v;
+					switched = TRUE;
+				}
+			}
+		}
+	}
+
+	{
 		int n = n2;
 
 		if (missing2)
@@ -514,6 +547,8 @@ gnumeric_interpolation (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 		}
 
 	}
+
+ done:
 	g_slist_free (missing2);
 	if (!constp) {
 		g_free (vals0);
@@ -1045,20 +1080,20 @@ gnumeric_hpfilter (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 const GnmFuncDescriptor TimeSeriesAnalysis_functions[] = {
 
         { "interpolation",       "AAA|f",
-	  help_interpolation, gnumeric_interpolation, NULL, NULL, NULL, NULL,
+	  help_interpolation, gnumeric_interpolation, NULL, NULL, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
 	{ "periodogram",       "A|fAff",
-	  help_periodogram, gnumeric_periodogram, NULL, NULL, NULL, NULL,
+	  help_periodogram, gnumeric_periodogram, NULL, NULL, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
 	{ "fourier",       "A|bb",
-	  help_fourier, gnumeric_fourier, NULL, NULL, NULL, NULL,
+	  help_fourier, gnumeric_fourier, NULL, NULL, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
 	{ "hpfilter",       "A|f",
-	  help_hpfilter, gnumeric_hpfilter, NULL, NULL, NULL, NULL,
+	  help_hpfilter, gnumeric_hpfilter, NULL, NULL, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
-	{NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0}
+	{NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0}
 };
