@@ -567,7 +567,7 @@ dialog_autoformat (WBCGtk *wbcg)
 	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
 
-	gui = gnm_gtk_builder_new ("autoformat.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("autoformat.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
 
