@@ -1154,7 +1154,7 @@ dialog_function_select_load_tree (FunctionSelectState *state)
 				 FUNCTION_CAT, func->fn_group,
 				 FUNCTION_VISIBLE, TRUE,
 				 FUNCTION_RECENT, FALSE,
-				 FUNCTION_USED, (func->ref_count > 1),
+				 FUNCTION_USED, (func->usage_count > 1),
 				 -1);
 			g_free (desc);
 			pango_attr_list_unref (pal);
@@ -1373,7 +1373,7 @@ dialog_function_select_full (WBCGtk *wbcg, char const *guru_key,
 
 	if (gnumeric_dialog_raise_if_exists (wbcg, key))
 		return;
-	gui = gnm_gtk_builder_new ("function-select.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("function-select.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
 		return;
 
