@@ -1312,7 +1312,7 @@ dialog_preferences (WBCGtk *wbcg, gchar const *page)
 		return;
 	}
 
-	gui = gnm_gtk_builder_new ("preferences.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("preferences.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
 
