@@ -1722,7 +1722,7 @@ do_hf_customize (gboolean header, PrinterSetupState *state)
 		return;
 	}
 
-	gui = gnm_gtk_builder_new ("hf-config.ui", NULL, GO_CMD_CONTEXT (state->wbcg));
+	gui = gnm_gtk_builder_load ("hf-config.ui", NULL, GO_CMD_CONTEXT (state->wbcg));
         if (gui == NULL)
                 return;
 
@@ -1883,7 +1883,7 @@ do_hf_dt_format_customize (gboolean date, HFCustomizeState *hf_state)
 	gint result;
 	char *result_string = NULL;
 
-	gui = gnm_gtk_builder_new ("hf-dt-format.ui", NULL,
+	gui = gnm_gtk_builder_load ("hf-dt-format.ui", NULL,
 	                         GO_CMD_CONTEXT (hf_state->printer_setup_state->wbcg));
         if (gui == NULL)
                 return NULL;
@@ -2826,7 +2826,7 @@ printer_setup_state_new (WBCGtk *wbcg, Sheet *sheet)
 	PrinterSetupState *state;
 	GtkBuilder *gui;
 
-	gui = gnm_gtk_builder_new ("print.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("print.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return NULL;
 
