@@ -132,8 +132,8 @@ summary_cb (int col, int row, GnmValue *v, summary_cb_t *p)
 		/* Set the colors. */
 		dao_set_colors (&p->dao, 2 + p->col, 3 + *index,
 				2 + p->col, 3 + *index,
-				style_color_new_go (GO_COLOR_BLACK),
-				style_color_new_gdk (&gs_light_gray));
+				gnm_color_new_go (GO_COLOR_BLACK),
+				gnm_color_new_gdk (&gs_light_gray));
 
 	} else {
 		/* New cell. */
@@ -155,8 +155,8 @@ summary_cb (int col, int row, GnmValue *v, summary_cb_t *p)
 		/* Set the colors. */
 		dao_set_colors (&p->dao, 2 + p->col, 3 + p->row,
 				2 + p->col, 3 + p->row,
-				style_color_new_go (GO_COLOR_BLACK),
-				style_color_new_gdk (&gs_light_gray));
+				gnm_color_new_go (GO_COLOR_BLACK),
+				gnm_color_new_gdk (&gs_light_gray));
 
 		/* Insert row number into the hash table. */
 		r  = g_new (int, 1);
@@ -227,11 +227,11 @@ scenario_summary (WorkbookControl *wbc,
 	dao_set_cell (&cb.dao, 0, 0, _("Scenario Summary"));
 
 	dao_set_colors (&cb.dao, 0, 0, cb.col + 1, 1,
-			style_color_new_go (GO_COLOR_WHITE),
-			style_color_new_gdk (&gs_dark_gray));
+			gnm_color_new_go (GO_COLOR_WHITE),
+			gnm_color_new_gdk (&gs_dark_gray));
 	dao_set_colors (&cb.dao, 0, 2, 0, 2 + cb.row,
-			style_color_new_go (GO_COLOR_BLACK),
-			style_color_new_gdk (&gs_light_gray));
+			gnm_color_new_go (GO_COLOR_BLACK),
+			gnm_color_new_gdk (&gs_light_gray));
 
 	dao_set_align (&cb.dao, 1, 1, cb.col + 1, 1, GNM_HALIGN_RIGHT,
 		       GNM_VALIGN_BOTTOM);
