@@ -54,11 +54,11 @@ functions_shutdown (void)
 {
 	while (unknown_cat != NULL && unknown_cat->functions != NULL) {
 		GnmFunc *func = unknown_cat->functions->data;
-		if (func->ref_count > 0) {
-			g_warning ("Function %s still has %d refs.\n",
+		if (func->usage_count > 0) {
+			g_warning ("Function %s still has %d users.\n",
 				   gnm_func_get_name (func, FALSE),
-				   func->ref_count);
-			func->ref_count = 0;
+				   func->usage_count);
+			func->usage_count = 0;
 		}
 		gnm_func_free (func);
 	}
@@ -122,8 +122,8 @@ cb_dump_usage (gpointer key, Symbol *sym, FILE *out)
 {
 	if (sym != NULL) {
 		GnmFunc const *fd = sym->data;
-		if (fd != NULL && fd->ref_count > 0)
-			fprintf (out, "%d,%s\n", fd->ref_count, fd->name);
+		if (fd != NULL && fd->usage_count > 0)
+			fprintf (out, "%d,%s\n", fd->usage_count, fd->name);
 	}
 }
 
@@ -776,11 +776,34 @@ gnm_func_group_free (GnmFuncGroup *fn_group)
 	g_return_if_fail (fn_group != NULL);
 	g_return_if_fail (fn_group->functions == NULL);
 
+	if (fn_group->ref_count-- > 1)
+		return;
+
 	go_string_unref (fn_group->internal_name);
 	go_string_unref (fn_group->display_name);
 	g_free (fn_group);
 }
 
+static GnmFuncGroup * 
+gnm_func_group_ref (GnmFuncGroup *fn_group)
+{
+	fn_group->ref_count++;
+	return fn_group;
+}
+
+GType
+gnm_func_group_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GnmFuncGroup",
+			 (GBoxedCopyFunc)gnm_func_group_ref,
+			 (GBoxedFreeFunc)gnm_func_group_free);
+	}
+	return t;
+}
+
 static gint
 function_category_compare (gconstpointer a, gconstpointer b)
 {
@@ -808,6 +831,7 @@ gnm_func_group_fetch (char const *name, char const *translation)
 	if (l == NULL) {
 		cat = g_new (GnmFuncGroup, 1);
 		cat->internal_name = go_string_new (name);
+		cat->ref_count = 1;
 		if (translation != NULL) {
 			cat->display_name = go_string_new (translation);
 			cat->has_translation = TRUE;
@@ -926,7 +950,6 @@ gnm_func_load_stub (GnmFunc *func)
 			g_warning ("Invalid function descriptor with no function");
 		}
 		func->linker	  = desc.linker;
-		func->unlinker	  = desc.unlinker;
 		func->impl_status = desc.impl_status;
 		func->test_status = desc.test_status;
 		func->flags	  = desc.flags;
@@ -936,7 +959,6 @@ gnm_func_load_stub (GnmFunc *func)
 		func->fn_type = GNM_FUNC_TYPE_NODES;
 		func->fn.nodes = &error_function_no_full_info;
 		func->linker   = NULL;
-		func->unlinker = NULL;
 	}
 }
 
@@ -947,7 +969,7 @@ gnm_func_free (GnmFunc *func)
 	GnmFuncGroup *group;
 
 	g_return_if_fail (func != NULL);
-	g_return_if_fail (func->ref_count == 0);
+	g_return_if_fail (func->usage_count == 0);
 
 	group = func->fn_group;
 	if (group != NULL) {
@@ -982,25 +1004,39 @@ gnm_func_free (GnmFunc *func)
 	g_free (func);
 }
 
-void
+GnmFunc *
 gnm_func_ref (GnmFunc *func)
 {
-	g_return_if_fail (func != NULL);
+	g_return_val_if_fail (func != NULL, NULL);
 
-	func->ref_count++;
-	if (func->ref_count == 1 && func->ref_notify != NULL)
-		func->ref_notify (func, 1);
+	func->usage_count++;
+	if (func->usage_count == 1 && func->usage_notify != NULL)
+		func->usage_notify (func, 1);
+	return func;
 }
 
 void
 gnm_func_unref (GnmFunc *func)
 {
 	g_return_if_fail (func != NULL);
-	g_return_if_fail (func->ref_count > 0);
+	g_return_if_fail (func->usage_count > 0);
 
-	func->ref_count--;
-	if (func->ref_count == 0 && func->ref_notify != NULL)
-		func->ref_notify (func, 0);
+	func->usage_count--;
+	if (func->usage_count == 0 && func->usage_notify != NULL)
+		func->usage_notify (func, 0);
+}
+
+GType
+gnm_func_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GnmFunc",
+			 (GBoxedCopyFunc)gnm_func_ref,
+			 (GBoxedFreeFunc)gnm_func_unref);
+	}
+	return t;
 }
 
 /**
@@ -1016,6 +1052,13 @@ gnm_func_lookup (char const *name, Workbook *scope)
 	return g_hash_table_lookup (scope->sheet_local_functions, (gpointer)name);
 }
 
+/**
+ * gnm_func_lookup_prefix:
+ * @prefix:
+ * @scope:
+ *
+ * Returns: (element-type GnmFunc*) (transfer full):
+ **/
 GSList *
 gnm_func_lookup_prefix   (char const *prefix, Workbook *scope)
 {
@@ -1045,15 +1088,14 @@ gnm_func_add (GnmFuncGroup *fn_group,
 	func->help		= desc->help ? desc->help : NULL;
 	func->textdomain        = go_string_new (textdomain);
 	func->linker		= desc->linker;
-	func->unlinker		= desc->unlinker;
-	func->ref_notify	= desc->ref_notify;
+	func->usage_notify	= desc->usage_notify;
 	func->flags		= desc->flags;
 	func->impl_status	= desc->impl_status;
 	func->test_status	= desc->test_status;
 	func->localized_name    = NULL;
 
 	func->user_data		= NULL;
-	func->ref_count		= 0;
+	func->usage_count	= 0;
 
 	if (desc->fn_args != NULL) {
 		/* Check those arguments */
@@ -1099,12 +1141,20 @@ unknownFunctionHandler (GnmFuncEvalInfo *ei,
 	return value_new_error_NAME (ei->pos);
 }
 
+/**
+ * gnm_func_add_stub:
+ * @fn_group:
+ * @name:
+ * @textdomain:
+ * @load_desc: (scope async):
+ * @opt_usage_notify: (scope async):
+ **/
 GnmFunc *
 gnm_func_add_stub (GnmFuncGroup *fn_group,
 		   const char *name,
 		   const char *textdomain,
 		   GnmFuncLoadDesc   load_desc,
-		   GnmFuncRefNotify  opt_ref_notify)
+		   GnmFuncUsageNotify opt_usage_notify)
 {
 	GnmFunc *func = g_new0 (GnmFunc, 1);
 
@@ -1112,7 +1162,7 @@ gnm_func_add_stub (GnmFuncGroup *fn_group,
 		textdomain = GETTEXT_PACKAGE;
 
 	func->name		= name;
-	func->ref_notify	= opt_ref_notify;
+	func->usage_notify	= opt_usage_notify;
 	func->fn_type		= GNM_FUNC_TYPE_STUB;
 	func->fn.load_desc	= load_desc;
 	func->textdomain        = go_string_new (textdomain);
@@ -1155,8 +1205,7 @@ gnm_func_add_placeholder (Workbook *scope,
 	desc.fn_args	  = NULL;
 	desc.fn_nodes	  = &unknownFunctionHandler;
 	desc.linker	  = NULL;
-	desc.unlinker	  = NULL;
-	desc.ref_notify	  = NULL;
+	desc.usage_notify = NULL;
 	desc.flags	  = GNM_FUNC_IS_PLACEHOLDER | (copy_name ? GNM_FUNC_FREE_NAME : 0);
 	desc.impl_status  = GNM_FUNC_IMPL_STATUS_EXISTS;
 	desc.test_status  = GNM_FUNC_TEST_STATUS_UNKNOWN;
@@ -1191,7 +1240,12 @@ gnm_func_lookup_or_add_placeholder (char const *name, Workbook *scope, gboolean
 	return f;
 }
 
-
+/**
+ * gnm_func_get_user_data:
+ * @func:
+ *
+ * Returns: (transfer none):
+ **/
 gpointer
 gnm_func_get_user_data (GnmFunc const *func)
 {
@@ -1277,7 +1331,7 @@ gnm_func_get_description (GnmFunc const *fn_def)
 
 /**
  * function_def_count_args:
- * @func: pointer to function definition
+ * @fn_def: pointer to function definition
  * @min: pointer to min. args
  * @max: pointer to max. args
  *
@@ -1930,10 +1984,11 @@ function_iterate_do_value (GnmEvalPos const  *ep,
 /**
  * function_iterate_argument_values
  *
- * @fp:               The position in a workbook at which to evaluate
- * @callback:         The routine to be invoked for every value computed
+ * @ep:               The position in a workbook at which to evaluate
+ * @callback: (scope call): The routine to be invoked for every value computed
  * @callback_closure: Closure for the callback.
- * @expr_node_list:   a GnmExprList of ExprTrees (what a Gnumeric function would get).
+ * @argc:
+ * @argv:
  * @strict:           If TRUE, the function is considered "strict".  This means
  *                   that if an error value occurs as an argument, the iteration
  *                   will stop and that error will be returned.  If FALSE, an
