@@ -964,6 +964,6 @@ gnm_plugins_init (GOCmdContext *context)
 			 gnm_conf_get_plugins_file_states (),
 			 gnm_conf_get_plugins_active (),
 			 dir_list,
-			 gnm_conf_get_plugins_activate_new (),
+			 gnm_conf_get_plugins_activate_newplugins (),
 			 gnm_plugin_loader_module_get_type ());
 }
