@@ -561,10 +561,12 @@ gnm_go_data_vector_load_len (GODataVector *dat)
 			gnm_rangeref_normalize (&vec->val->v_range.cell, &ep,
 				&start_sheet, &end_sheet, &r);
 
+			/* add +1 to max_used so that we can have matrices with
+			 * empty cells at the end, see #684072 */
 			if (r.end.col > start_sheet->cols.max_used)
-				r.end.col = start_sheet->cols.max_used;
+				r.end.col = start_sheet->cols.max_used + 1;
 			if (r.end.row > start_sheet->rows.max_used)
-				r.end.row = start_sheet->rows.max_used;
+				r.end.row = start_sheet->rows.max_used + 1;
 
 			if (r.end.col >= r.start.col && r.end.row >= r.start.row) {
 				w = range_width (&r);
@@ -682,11 +684,13 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 			&start_sheet, &end_sheet, &r);
 
 		/* clip here rather than relying on sheet_foreach
-		 * because that only clips if we ignore blanks */
+		 * because that only clips if we ignore blanks 
+		 * but add +1 to max_used so that we can have matrices with
+		 * empty cells at the end, see #684072 */
 		if (r.end.row > start_sheet->rows.max_used)
-			r.end.row = start_sheet->rows.max_used;
+			r.end.row = start_sheet->rows.max_used + 1;
 		if (r.end.col > start_sheet->cols.max_used)
-			r.end.col = start_sheet->cols.max_used;
+			r.end.col = start_sheet->cols.max_used + 1;
 
 		/* In case the sheet is empty */
 		if (r.start.col <= r.end.col && r.start.row <= r.end.row) {
@@ -695,7 +699,7 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 			closure.vals = dat->values;
 			closure.last = -1;
 			closure.i = 0;
-			sheet_foreach_cell_in_range (start_sheet, CELL_ITER_ALL,
+			sheet_foreach_cell_in_range (start_sheet, CELL_ITER_IGNORE_SUBTOTAL,
 				r.start.col, r.start.row, r.end.col, r.end.row,
 				(CellIterFunc)cb_assign_val, &closure);
 			dat->len = closure.last + 1; /* clip */
@@ -733,7 +737,7 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 					closure.vals = dat->values;
 					closure.last = last - 1;
 					closure.i = last;
-					sheet_foreach_cell_in_range (start_sheet, CELL_ITER_ALL,
+					sheet_foreach_cell_in_range (start_sheet, CELL_ITER_IGNORE_SUBTOTAL,
 						r.start.col, r.start.row, r.end.col, r.end.row,
 						(CellIterFunc)cb_assign_val, &closure);
 					last = dat->len = closure.last + 1; /* clip */
@@ -882,7 +886,7 @@ gnm_go_data_vector_get_str (GODataVector *dat, unsigned i)
 					r.end.col = start_sheet->cols.max_used;
 
 				if (r.start.col <= r.end.col && r.start.row <= r.end.row)
-					sheet_foreach_cell_in_range (start_sheet, CELL_ITER_ALL,
+					sheet_foreach_cell_in_range (start_sheet, CELL_ITER_IGNORE_SUBTOTAL,
 						r.start.col, r.start.row, r.end.col, r.end.row,
 						(CellIterFunc)cb_assign_string, vec->strs);
 			}
