@@ -151,7 +151,7 @@ text_to_cell_region (WBCGtk *wbcg,
 	if (oneline) {
 		GODateConventions const *date_conv = workbook_date_conv (wb);
 		GnmCellCopy *cc = gnm_cell_copy_new (
-			(cr = cellregion_new (NULL)), 0, 0);
+			(cr = gnm_cell_region_new (NULL)), 0, 0);
 		char *tmp = g_strndup (data, data_len);
 
 		g_free (data_converted);
@@ -172,13 +172,13 @@ text_to_cell_region (WBCGtk *wbcg,
 		if (dialogresult != NULL) {
 			cr = stf_parse_region (dialogresult->parseoptions,
 					       dialogresult->text, NULL, wb);
-			g_return_val_if_fail (cr != NULL, cellregion_new (NULL));
+			g_return_val_if_fail (cr != NULL, gnm_cell_region_new (NULL));
 
 			stf_dialog_result_attach_formats_to_cr (dialogresult, cr);
 
 			stf_dialog_result_free (dialogresult);
 		} else
-			cr = cellregion_new (NULL);
+			cr = gnm_cell_region_new (NULL);
 	}
 
 	return cr;
@@ -279,7 +279,7 @@ utf8_content_received (GtkClipboard *clipboard,  const gchar *text,
  * as well, but the file_opener service makes workbooks, not sheets.
  *
  * We use the file_opener service by wrapping the selection data in a GsfInput,
- * and calling wb_view_new_from_input.
+ * and calling workbook_view_new_from_input.
  **/
 static GnmCellRegion *
 table_cellregion_read (WorkbookControl *wbc, char const *reader_id,
@@ -299,7 +299,7 @@ table_cellregion_read (WorkbookControl *wbc, char const *reader_id,
 
 	ioc = go_io_context_new (GO_CMD_CONTEXT (wbc));
 	input = gsf_input_memory_new (buffer, length, FALSE);
-	wb_view = wb_view_new_from_input  (input, NULL, reader, ioc, NULL);
+	wb_view = workbook_view_new_from_input  (input, NULL, reader, ioc, NULL);
 	if (go_io_error_occurred (ioc) || wb_view == NULL) {
 		go_io_error_display (ioc);
 		goto out;
@@ -480,12 +480,11 @@ table_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 	/* Nothing on clipboard? */
 	if (gtk_selection_data_get_length (sel) < 0) {
 		;
-	} else if (target == gdk_atom_intern (GNUMERIC_ATOM_NAME,
-						   FALSE)) {
+	} else if (target == gdk_atom_intern (GNUMERIC_ATOM_NAME, FALSE)) {
 		/* The data is the gnumeric specific XML interchange format */
 		GOIOContext *io_context =
 			go_io_context_new (GO_CMD_CONTEXT (wbcg));
-		content = xml_cellregion_read
+		content = gnm_xml_cellregion_read
 			(wbc, io_context,
 			 pt->sheet,
 			 (const char *)gtk_selection_data_get_data (sel), gtk_selection_data_get_length (sel));
@@ -702,7 +701,7 @@ table_cellregion_write (GOCmdContext *ctx, GnmCellRegion *cr,
 			   PASTE_AS_VALUES | PASTE_FORMATS |
 			   PASTE_COMMENTS | PASTE_OBJECTS);
 	if (clipboard_paste_region (cr, &pt, ctx) == FALSE) {
-		go_file_saver_save (saver, ioc, wb_view, output);
+		go_file_saver_save (saver, ioc, GO_VIEW (wb_view), output);
 		if (!go_io_error_occurred (ioc)) {
 			GsfOutputMemory *omem = GSF_OUTPUT_MEMORY (output);
 			gsf_off_t osize = gsf_output_size (output);
@@ -983,6 +982,9 @@ static gint
 x_clipboard_clear_cb (GtkClipboard *clipboard,
 		      GObject *obj)
 {
+	if (debug_clipboard ())
+		g_printerr ("Lost clipboard ownership.\n");
+
 	gnm_app_clipboard_clear (FALSE);
 
 	return TRUE;
@@ -1117,6 +1119,8 @@ gnm_x_claim_clipboard (WBCGtk *wbcg)
 		(GtkClipboardClearFunc) x_clipboard_clear_cb,
 		gnm_app_get_app ());
 	if (ret) {
+		if (debug_clipboard ())
+			g_printerr ("Clipboard successfully claimed.\n");
 		set_clipman_targets (display, targets, n_targets);
 		ret = gtk_clipboard_set_with_owner (
 			gtk_clipboard_get_for_display (display,
@@ -1125,6 +1129,9 @@ gnm_x_claim_clipboard (WBCGtk *wbcg)
 			(GtkClipboardGetFunc) x_clipboard_get_cb,
 			NULL,
 			gnm_app_get_app ());
+	} else {
+		if (debug_clipboard ())
+			g_printerr ("Failed to claim clipboard.\n");
 	}
 	if (exportable || imageable)
 		gtk_target_table_free (targets, n_targets);
