@@ -91,6 +91,28 @@ get_top_left (ItemEdit const *ie, int *top, int *left, PangoDirection dir)
 	}
 }
 
+static gboolean
+gnm_apply_attribute_list_cb (PangoAttribute *attribute,
+			     gpointer data)
+{
+	PangoAttrList *attrs = data;
+	if (attribute->klass->type == PANGO_ATTR_FOREGROUND) {
+		PangoAttribute *copy = pango_attribute_copy (attribute);
+		pango_attr_list_change (attrs, copy);
+	}
+	return FALSE;
+}
+
+static void
+gnm_apply_attribute_list (PangoAttrList *attrs, PangoAttrList *added_attrs)
+{
+	if (added_attrs == NULL)
+		return;
+	pango_attr_list_unref (pango_attr_list_filter (added_attrs,
+						       gnm_apply_attribute_list_cb,
+						       attrs));
+}
+
 static void
 item_edit_draw (GocItem const *item, cairo_t *cr)
 {
@@ -102,6 +124,16 @@ item_edit_draw (GocItem const *item, cairo_t *cr)
 	PangoRectangle pos, weak;
 	char const *text = gtk_entry_get_text (ie->entry);
 	PangoDirection dir = pango_find_base_dir (text, -1);
+	PangoAttrList *entry_attributes
+		= g_object_get_data(G_OBJECT (ie->entry),
+				    "gnm:range-attributes");
+
+	if (entry_attributes != NULL) {
+		if (go_pango_attr_list_is_empty (entry_attributes))
+			entry_attributes = NULL;
+		else
+			entry_attributes = pango_attr_list_ref (entry_attributes);
+	}
 
 	get_top_left (ie, &top, &left, dir);
 	if (goc_canvas_get_direction (item->canvas) == GOC_DIRECTION_RTL) {
@@ -136,35 +168,41 @@ item_edit_draw (GocItem const *item, cairo_t *cr)
 	cairo_move_to (cr, left, top);
 	gtk_editable_get_selection_bounds (GTK_EDITABLE (ie->entry), &start, &end);
 	if (start != end) {
-		unsigned r, g, b;
 		PangoAttribute *attr;
 		PangoAttrList *orig = pango_attr_list_ref (pango_layout_get_attributes (ie->layout)),
 			*attrs = pango_attr_list_copy (orig);
 		start = g_utf8_offset_to_pointer (text, start) - text;
 		end = g_utf8_offset_to_pointer (text, end) - text;
 		color = gnm_style_get_back_color (ie->style)->go_color;
-		r = (GO_COLOR_UINT_R (color) ^ 0xff) * 0x101;
-		g = (GO_COLOR_UINT_G (color) ^ 0xff) * 0x101;
-		b = (GO_COLOR_UINT_B (color) ^ 0xff) * 0x101;
-		attr = pango_attr_background_new (r, g, b);
+		attr = go_color_to_pango (color, FALSE);
 		attr->start_index = start;
 		attr->end_index = end;
 		pango_attr_list_change (attrs, attr);
 		color = gnm_style_get_font_color (ie->style)->go_color;
-		r = (GO_COLOR_UINT_R (color) ^ 0xff) * 0x101;
-		g = (GO_COLOR_UINT_G (color) ^ 0xff) * 0x101;
-		b = (GO_COLOR_UINT_B (color) ^ 0xff) * 0x101;
-		attr = pango_attr_foreground_new (r, g, b);
+		attr = go_color_to_pango (color, TRUE);
 		attr->start_index = start;
 		attr->end_index = end;
 		pango_attr_list_change (attrs, attr);
+		gnm_apply_attribute_list (attrs, entry_attributes);
 		pango_layout_set_attributes (ie->layout, attrs);
 		pango_attr_list_unref (attrs);
 		pango_cairo_show_layout (cr, ie->layout);
 		pango_layout_set_attributes (ie->layout, orig);
 		pango_attr_list_unref (orig);
-	} else
+	} else if (entry_attributes != NULL) {
+		PangoAttrList *orig = pango_attr_list_ref (pango_layout_get_attributes (ie->layout)),
+			*attrs = pango_attr_list_copy (orig);
+		gnm_apply_attribute_list (attrs, entry_attributes);
+		pango_layout_set_attributes (ie->layout, attrs);
+		pango_attr_list_unref (attrs);
 		pango_cairo_show_layout (cr, ie->layout);
+		pango_layout_set_attributes (ie->layout, orig);
+		pango_attr_list_unref (orig);
+	} else {
+		pango_cairo_show_layout (cr, ie->layout);
+	}
+	pango_attr_list_unref (entry_attributes);
+
 	if (ie->cursor_visible) {
 		int cursor_pos = gtk_editable_get_position (GTK_EDITABLE (ie->entry));
 		double incr = (dir == PANGO_DIRECTION_RTL)? -.5: .5, x, ytop, ybottom;
@@ -222,7 +260,7 @@ item_edit_distance (GocItem *item, double cx, double cy,
 }
 
 static gboolean
-item_edit_enter_notify (GocItem *item, double x, double y)
+item_edit_enter_notify (GocItem *item, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
 	gnm_widget_set_cursor_type (GTK_WIDGET (item->canvas), GDK_XTERM);
 	return TRUE;
@@ -340,7 +378,8 @@ item_edit_motion (GocItem *item, double x, double y)
 }
 
 static gboolean
-item_edit_button_released (GocItem *item, int button, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
+item_edit_button_released (GocItem *item, G_GNUC_UNUSED int button,
+			   G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
 	ItemEdit *ie = ITEM_EDIT (item);
 	if (ie->sel_start >= 0) {
