@@ -670,7 +670,7 @@ gnm_style_dup (GnmStyle const *src)
  * A new GnmStyle that contains any elements of @overlay that are set, and uses
  * @base for anything that is not set in @overlay.
  *
- * Returns A ref to a new GnmStyle.
+ * Returns: (transfer full): A ref to a new GnmStyle.
  **/
 GnmStyle *
 gnm_style_new_merged (GnmStyle const *base, GnmStyle const *overlay)
@@ -737,6 +737,19 @@ gnm_style_unref (GnmStyle const *style)
 	}
 }
 
+GType
+gnm_style_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GnmStyle",
+			 (GBoxedCopyFunc)gnm_style_ref,
+			 (GBoxedFreeFunc)gnm_style_unref);
+	}
+	return t;
+}
+
 /**
  * Replace auto pattern color in style with sheet's auto pattern color.
  * make_copy tells if we are allowed to modify the style in place or we must
@@ -1210,6 +1223,13 @@ gnm_style_get_pattern (GnmStyle const *style)
 	return style->pattern;
 }
 
+/**
+ * gnm_style_get_font:
+ * @style: #GnmStyle
+ * @context: #PangoContext
+ *
+ * Returns: (transfer none):
+ **/
 GnmFont *
 gnm_style_get_font (GnmStyle const *style, PangoContext *context)
 {
@@ -1636,6 +1656,12 @@ gnm_style_set_validation (GnmStyle *style, GnmValidation *v)
 	style->validation = v;
 }
 
+/**
+ * gnm_style_get_validation:
+ * @style: #GnmStyle
+ *
+ * Returns: (transfer none):
+ **/
 GnmValidation const *
 gnm_style_get_validation (GnmStyle const *style)
 {
@@ -1656,6 +1682,12 @@ gnm_style_set_hlink (GnmStyle *style, GnmHLink *link)
 	style->hlink = link;
 }
 
+/**
+ * gnm_style_get_hlink:
+ * @style: #GnmStyle
+ *
+ * Returns: (transfer none): the associated #GnmHLink.
+ **/
 GnmHLink *
 gnm_style_get_hlink (GnmStyle const *style)
 {
@@ -1676,6 +1708,12 @@ gnm_style_set_input_msg (GnmStyle *style, GnmInputMsg *msg)
 	style->input_msg = msg;
 }
 
+/**
+ * gnm_style_get_input_msg:
+ * @style: #GnmStyle
+ *
+ * Returns: (transfer none):
+ **/
 GnmInputMsg *
 gnm_style_get_input_msg (GnmStyle const *style)
 {
@@ -1696,6 +1734,12 @@ gnm_style_set_conditions (GnmStyle *style, GnmStyleConditions *sc)
 	style->conditions = sc;
 }
 
+/**
+ * gnm_style_get_conditions:
+ * @style: #GnmStyle
+ *
+ * Returns: (transfer none):
+ **/
 GnmStyleConditions *
 gnm_style_get_conditions (GnmStyle const *style)
 {
@@ -1879,7 +1923,7 @@ gnm_style_set_from_pango_attribute (GnmStyle *style, PangoAttribute const *attr)
 			((PangoAttrInt *)attr)->value >= PANGO_WEIGHT_BOLD);
 		break;
 	case PANGO_ATTR_FOREGROUND :
-		gnm_style_set_font_color (style, style_color_new_pango (
+		gnm_style_set_font_color (style, gnm_color_new_pango (
 			&((PangoAttrColor *)attr)->color));
 		break;
 	case PANGO_ATTR_UNDERLINE :
