@@ -3242,7 +3242,7 @@ yylex (void)
 			gnm_float d;
 
 			errno = 0;
-			d = gnm_strto (start, &end);
+			d = gnm_utf8_strto (start, &end);
 			if (start == end) {
 				g_warning ("%s is not a double, but was expected to be one", start);
 			}  else if (errno != ERANGE) {
@@ -3267,8 +3267,7 @@ yylex (void)
 			char *end;
 			long l;
 
-			errno = 0;
-			l = strtol (start, &end, 10);
+			l = gnm_utf8_strtol (start, &end);
 			if (start == end) {
 				g_warning ("%s is not an integer, but was expected to be one", start);
 			} else if (errno != ERANGE && l >= INT_MIN && l <= INT_MAX) {
@@ -3278,7 +3277,7 @@ yylex (void)
 				gnm_float d;
 
 				errno = 0;
-				d = gnm_strto (start, &end);
+				d = gnm_utf8_strto (start, &end);
 				if (errno != ERANGE) {
 					v = value_new_float (d);
 					state->ptr = end;
