@@ -161,7 +161,8 @@ range_parse (GnmRange *r, char const *text, GnmSheetSize const *ss)
 
 /**
  * range_list_destroy:
- * @ranges: a list of value ranges to destroy.
+ * @ranges: (element-type GnmValue) (transfer full):  a list of value ranges
+ * to destroy.
  *
  * Destroys a list of ranges returned from parse_cell_range_list
  **/
@@ -265,7 +266,7 @@ range_contained (GnmRange const *a, GnmRange const *b)
  * overlapping remainder of soft as the first list item
  * ( the central region in the pathalogical case ).
  *
- * Return value: A list of fragments.
+ * Returns: (element-type GnmRange) (transfer full): A list of fragments.
  **/
 GSList *
 range_split_ranges (GnmRange const *hard, GnmRange const *soft)
@@ -424,11 +425,11 @@ range_split_ranges (GnmRange const *hard, GnmRange const *soft)
 
 /**
  * gnm_range_dup:
- * @a: Source range to copy
+ * @r: Source range to copy
  *
- * Copies the @a range.
+ * Copies the @r range.
  *
- * Return value: A copy of the GnmRange.
+ * Returns: (transfer full): A copy of the GnmRange.
  **/
 GnmRange *
 gnm_range_dup (GnmRange const *a)
@@ -445,8 +446,8 @@ gnm_range_dup (GnmRange const *a)
  *
  * Fragments the ranges into totaly non-overlapping regions,
  *
- * Return value: A list of fragmented ranges or at minimum
- * simply a and b.
+ * Returns: (element-type GnmRange) (transfer full): A list of fragmented
+ * ranges or at minimum simply a and b.
  **/
 GSList *
 range_fragment (GnmRange const *a, GnmRange const *b)
@@ -498,7 +499,7 @@ range_intersection (GnmRange *r, GnmRange const *a, GnmRange const *b)
 
 /**
  * range_normalize:
- * @a: a range
+ * @src: a range
  *
  * Ensures that start <= end for rows and cols.
  **/
@@ -636,7 +637,7 @@ range_height (GnmRange const *r)
 /**
  * range_translate:
  * @range:
- * @sheet : the sheet in which @range lives
+ * @sheet: the sheet in which @range lives
  * @col_offset:
  * @row_offset:
  *
@@ -707,8 +708,8 @@ range_is_sane (GnmRange const *range)
 /**
  * range_transpose:
  * @range: The range.
- * @sheet : the sheet in which @range lives
- * @boundary: The box to transpose inside
+ * @sheet: the sheet in which @range lives
+ * @origin: The box to transpose inside
  *
  *   Effectively mirrors the ranges in 'boundary' around a
  * leading diagonal projected from offset.
@@ -830,6 +831,18 @@ gnm_sheet_range_free (GnmSheetRange *gr)
 	g_free (gr);
 }
 
+GType
+gnm_sheet_range_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0)
+		t = g_boxed_type_register_static ("GnmSheetRange",
+			 (GBoxedCopyFunc)gnm_sheet_range_dup,
+			 (GBoxedFreeFunc)gnm_sheet_range_free);
+	return t;
+}
+
 gboolean
 gnm_sheet_range_equal (const GnmSheetRange *a,
 		       const GnmSheetRange *b)
@@ -954,7 +967,7 @@ range_list_name_try (GString *names, char const *sheet, GSList const *ranges)
 /**
  * undo_range_list_name:
  * @sheet:
- * @ranges : GSList containing GnmRange *'s
+ * @ranges: (element-type GnmRange): GSList containing GnmRange *'s
  *
  * Returns the range list name depending on the preference setting.
  * (The result will be something like: "A1:C3, D4:E5"). The string will be
@@ -1003,12 +1016,13 @@ undo_range_list_name (Sheet const *sheet, GSList const *ranges)
 /**
  * global_range_list_parse:
  * @sheet: Sheet where the range specification is relatively parsed to
- * @str  : a range or list of ranges to parse (ex: "A1", "A1:B1,C2,Sheet2!D2:D4")
+ * @str: a range or list of ranges to parse (ex: "A1", "A1:B1,C2,Sheet2!D2:D4")
  *
  * Parses a list of ranges, relative to the @sheet and returns a list with the
  * results.
  *
- * Returns a GSList containing Values of type VALUE_CELLRANGE, or NULL on failure
+ * Returns: (element-type GnmValue) (transfer full): a GSList containing
+ * Values of type VALUE_CELLRANGE, or NULL on failure
  **/
 GSList *
 global_range_list_parse (Sheet *sheet, char const *str)
@@ -1052,6 +1066,16 @@ global_range_list_parse (Sheet *sheet, char const *str)
 	return g_slist_reverse (ranges);
 }
 
+/**
+ * global_range_list_foreach:
+ * @gr_list: (element-type GnmRange): list of ranges.
+ * @ep:
+ * @flags:
+ * @handler: (scope call):
+ * @closure: user data.
+ *
+ * Returns: (transfer none):
+ **/
 GnmValue *
 global_range_list_foreach (GSList *gr_list, GnmEvalPos const *ep,
 			   CellIterFlags flags,
@@ -1072,7 +1096,7 @@ global_range_list_foreach (GSList *gr_list, GnmEvalPos const *ep,
 
 /**
  * global_range_contained:
- * @sheet : The calling context #Sheet for references with sheet==NULL
+ * @sheet: The calling context #Sheet for references with sheet==NULL
  * @a:
  * @b:
  *
