@@ -85,10 +85,12 @@ gnm_filter_condition_new_double (GnmFilterOp op0, GnmValue *v0,
 }
 
 GnmFilterCondition *
-gnm_filter_condition_new_bucket (gboolean top, gboolean absolute, double n)
+gnm_filter_condition_new_bucket (gboolean top, gboolean absolute,
+				 gboolean rel_range, double n)
 {
 	GnmFilterCondition *res = g_new0 (GnmFilterCondition, 1);
-	res->op[0] = GNM_FILTER_OP_TOP_N | (top ? 0 : 1) | (absolute ? 0 : 2);
+	res->op[0] = GNM_FILTER_OP_TOP_N | (top ? 0 : 1) |
+		(absolute ? 0 : (rel_range ? 2 : 4));
 	res->op[1] = GNM_FILTER_UNUSED;
 	res->count = n;
 	return res;
@@ -123,6 +125,19 @@ gnm_filter_condition_free (GnmFilterCondition *cond)
 	g_free (cond);
 }
 
+GType
+gnm_filter_condition_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GnmFilterCondition",
+			 (GBoxedCopyFunc)gnm_filter_condition_dup,
+			 (GBoxedFreeFunc)gnm_filter_condition_free);
+	}
+	return t;
+}
+
 /*****************************************************************************/
 
 typedef struct  {
@@ -454,24 +469,43 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 			col, start_row, col, end_row,
 			(CellIterFunc) cb_filter_non_blanks, target_sheet);
 	else if (0x30 == (cond->op[0] & GNM_FILTER_OP_TYPE_MASK)) {
-		if (cond->op[0] & 0x2) { /* relative */
-			FilterPercentage data;
-			gnm_float	 offset;
+		if (cond->op[0] & GNM_FILTER_OP_PERCENT_MASK) { /* relative */
+			if (cond->op[0] & GNM_FILTER_OP_REL_N_MASK) {
+				FilterItems data;
+				data.find_max = (cond->op[0] & 0x1) ? FALSE : TRUE;
+				data.elements    = 0;
+				data.count  = 0.5 + cond->count * (end_row - start_row + 1) /100.;
+				if (data.count < 1)
+					data.count = 1;
+				data.vals   = g_alloca (sizeof (GnmValue *) * data.count);
+				sheet_foreach_cell_in_range (filter->sheet,
+							     CELL_ITER_IGNORE_HIDDEN | CELL_ITER_IGNORE_BLANK,
+							     col, start_row, col, end_row,
+							     (CellIterFunc) cb_filter_find_items, &data);
+				data.target_sheet = target_sheet;
+				sheet_foreach_cell_in_range (filter->sheet,
+							     CELL_ITER_IGNORE_HIDDEN,
+							     col, start_row, col, end_row,
+							     (CellIterFunc) cb_hide_unwanted_items, &data);
+			} else {
+				FilterPercentage data;
+				gnm_float	 offset;
 
-			data.find_max = (cond->op[0] & 0x1) ? FALSE : TRUE;
-			data.initialized = FALSE;
-			sheet_foreach_cell_in_range (filter->sheet,
-				CELL_ITER_IGNORE_HIDDEN | CELL_ITER_IGNORE_BLANK,
-				col, start_row, col, end_row,
-				(CellIterFunc) cb_filter_find_percentage, &data);
-			offset = (data.high - data.low) * cond->count / 100.;
-			data.high -= offset;
-			data.low  += offset;
-			data.target_sheet = target_sheet;
-			sheet_foreach_cell_in_range (filter->sheet,
-				CELL_ITER_IGNORE_HIDDEN,
-				col, start_row, col, end_row,
-				(CellIterFunc) cb_hide_unwanted_percentage, &data);
+				data.find_max = (cond->op[0] & 0x1) ? FALSE : TRUE;
+				data.initialized = FALSE;
+				sheet_foreach_cell_in_range (filter->sheet,
+							     CELL_ITER_IGNORE_HIDDEN | CELL_ITER_IGNORE_BLANK,
+							     col, start_row, col, end_row,
+							     (CellIterFunc) cb_filter_find_percentage, &data);
+				offset = (data.high - data.low) * cond->count / 100.;
+				data.high -= offset;
+				data.low  += offset;
+				data.target_sheet = target_sheet;
+				sheet_foreach_cell_in_range (filter->sheet,
+							     CELL_ITER_IGNORE_HIDDEN,
+							     col, start_row, col, end_row,
+							     (CellIterFunc) cb_hide_unwanted_percentage, &data);
+			}
 		} else { /* absolute */
 			FilterItems data;
 			data.find_max = (cond->op[0] & 0x1) ? FALSE : TRUE;
@@ -689,6 +723,19 @@ gnm_filter_unref (GnmFilter *filter)
 	g_free (filter);
 }
 
+GType
+gnm_filter_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GnmFilter",
+			 (GBoxedCopyFunc)gnm_filter_ref,
+			 (GBoxedFreeFunc)gnm_filter_unref);
+	}
+	return t;
+}
+
 void
 gnm_filter_remove (GnmFilter *filter)
 {
@@ -885,7 +932,7 @@ gnm_sheet_filter_intersect_rows (Sheet const *sheet, int from, int to)
 }
 
 GnmRange *
-gnm_sheet_filter_can_be_extended (G_GNUC_UNUSED Sheet const *sheet, 
+gnm_sheet_filter_can_be_extended (G_GNUC_UNUSED Sheet const *sheet,
 				  GnmFilter const *f, GnmRange const *r)
 {
 	if (r->start.row < f->r.start.row || r->end.row > f->r.end.row)
@@ -915,7 +962,7 @@ cb_remove_col_undo_free (struct cb_remove_col_undo *r)
 }
 
 static void
-cb_remove_col_undo (GnmFilter *filter, struct cb_remove_col_undo *r, 
+cb_remove_col_undo (GnmFilter *filter, struct cb_remove_col_undo *r,
 		    G_GNUC_UNUSED gpointer data)
 {
 	while (filter->fields->len <= r->col)
@@ -954,9 +1001,9 @@ gnm_filter_set_range (GnmFilter *filter, GnmRange *r)
 	int start = r->start.col;
 
 	filter->r = *r;
-	for (i = start; i < old_r.start.col; i++) 
+	for (i = start; i < old_r.start.col; i++)
 		gnm_filter_add_field (filter, i - start);
-	for (i = old_r.end.col + 1; i <= r->end.col; i++) 
+	for (i = old_r.end.col + 1; i <= r->end.col; i++)
 		gnm_filter_add_field (filter, i - start);
 }
 
@@ -1100,7 +1147,7 @@ gnm_sheet_filter_insdel_colrow (Sheet *sheet,
 					 (GFreeFunc)gnm_filter_unref,
 					 g_free);
 				*pundo = go_undo_combine (*pundo, u);
-			}			
+			}
 			gnm_filter_update_active (filter);
 			gnm_filter_reapply (filter);
 		}
