@@ -256,7 +256,7 @@ gnm_soi_get_target_list (SheetObject const *so)
 	GSList *mimes, *ptr;
 	GdkPixbuf *pixbuf = NULL;
 
-	if (soi->type == NULL || soi->image == NULL)
+	if (soi->type == NULL && soi->image != NULL)
 		pixbuf = go_image_get_pixbuf (soi->image);
 	mime_str = go_image_format_to_mime (soi->type);
 	if (mime_str) {
@@ -441,7 +441,15 @@ gnm_soi_write_xml_sax (SheetObject const *so, GsfXMLOut *output,
 		gsf_xml_out_add_cstr (output, "image-type", soi->type);
 	if (soi->image && go_image_get_name (soi->image)) {
 		gsf_xml_out_add_cstr (output, "name", go_image_get_name (soi->image));
-		go_doc_save_image (GO_DOC (sheet_object_get_sheet (so)->workbook), go_image_get_name (soi->image));
+		if (sheet_object_get_sheet (so))
+			go_doc_save_image (GO_DOC (sheet_object_get_sheet (so)->workbook), go_image_get_name (soi->image));
+		else {
+			/* looks that this may happen when pasting from another process, see #687414 */
+			gsize length;
+			guint8 const *data = go_image_get_data (soi->image, &length);
+			gsf_xml_out_add_uint (output, "size-bytes", length);
+			gsf_xml_out_add_base64 (output, NULL, data, length);
+		}
 	} else {
 		gsf_xml_out_add_uint (output, "size-bytes", soi->bytes.len);
 		gsf_xml_out_add_base64 (output, NULL, soi->bytes.data, soi->bytes.len);
@@ -462,6 +470,7 @@ gnm_soi_copy (SheetObject *dst, SheetObject const *src)
 	new_soi->crop_bottom	= soi->crop_bottom;
 	new_soi->crop_left	= soi->crop_left;
 	new_soi->crop_right	= soi->crop_right;
+	new_soi->image		= g_object_ref (soi->image);
 }
 
 static void
