@@ -15,6 +15,7 @@
 #include "gnumeric.h"
 #include "position.h"
 #include "parse-util.h"
+#include "application.h"
 #include "workbook.h"
 #include "workbook-priv.h"
 #include "workbook-control.h"
@@ -254,7 +255,7 @@ read_files_to_merge (const char *inputs[], GOFileOpener *fo,
 		const char *fname = *inputs;
 		char *uri = go_shell_arg_to_uri (fname);
 		WorkbookView *wbv =
-			wb_view_new_from_uri (uri, fo, io_context,
+			workbook_view_new_from_uri (uri, fo, io_context,
 					      ssconvert_import_encoding);
 		g_free (uri);
 		inputs++;
@@ -593,7 +594,7 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 
 	io_context = go_io_context_new (cc);
 	if (mergeargs == NULL) {
-		wbv = wb_view_new_from_uri (infile, fo,
+		wbv = workbook_view_new_from_uri (infile, fo,
 					    io_context,
 					    ssconvert_import_encoding);
 	} else {
@@ -637,8 +638,7 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 
 	if (ssconvert_recalc)
 		workbook_recalc_all (wb);
-	else
-		workbook_recalc (wb);
+	gnm_app_recalc ();
 
 	if (ssconvert_range)
 		setup_range (G_OBJECT (wb),
@@ -730,6 +730,7 @@ main (int argc, char const **argv)
 		/* FIXME: What do we want to do here? */
 		go_error_info_free (plugin_errs);
 	}
+	go_component_set_default_command_context (cc);
 
 	if (ssconvert_list_exporters)
 		list_them (&go_get_file_savers,
@@ -750,6 +751,7 @@ main (int argc, char const **argv)
 		res = 1;
 	}
 
+	go_component_set_default_command_context (NULL);
 	g_object_unref (cc);
 	gnm_shutdown ();
 	gnm_pre_parse_shutdown ();
